@@ -7,11 +7,11 @@
 #include "../UpdateListener.h"
 #include "Request.h"
 
-#include <gtk--/dialog.h>
-#include <gtk--/label.h>
-#include <gtk--/combo.h>
-#include <gtk--/button.h>
-#include <gtk--/menu.h>
+#include <gtkmm/dialog.h>
+#include <gtkmm/label.h>
+#include <gtkmm/combo.h>
+#include <gtkmm/button.h>
+#include <gtkmm/menu.h>
 
 class MidiController;
 class PresetController;
@@ -19,14 +19,14 @@ class ControllerMapDialog : public Gtk::Window, public UpdateListener
 {
 public:
 		ControllerMapDialog	( int pipe_d,
-					MidiController & mc,
-					PresetController & pc );
+					MidiController* mc,
+					PresetController* pc );
 		~ControllerMapDialog	( );
     
 	void	update			( );
 	gint	popup_menu		( GdkEvent * event );
 	void	midi_select_controller	( );
-	void	select_controller	( int cc );
+	void	select_controller	( unsigned int cc );
 	void	select_parameter	( );
         gint	delete_event_impl	( GdkEventAny * ) 
 			{ hide_all(); return 0; };
