@@ -1,42 +1,29 @@
 /* amSynth
- * (c) 2001-2003 Nick Dowell
+ * (c) 2001-2004 Nick Dowell
  */
 
 #ifndef _GUI_H
 #define _GUI_H
 
 #include <string>
-#include <gtk--/box.h>
-#include <gtk--/main.h>
-#include <gtk--/frame.h>
-#include <gtk--/fixed.h>
-#include <gtk--/style.h>
-#include <gtk--/dialog.h>
-#include <gtk--/menu.h>
-#include <gtk--/menubar.h>
-#include <gtk--/menuitem.h>
-#include <gtk--/tearoffmenuitem.h>
-#include <gtk--/label.h>
-#include <gtk--/button.h>
-#include <gtk--/statusbar.h>
-#include <gtk--/pixmap.h>
-#include <gtk--/fileselection.h> 
-#include <gtk--/fontselection.h>
+#include <gtkmm.h>
 
-#include "../PresetController.h"
 #include "PresetControllerView.h"
 #include "ControllerMapDialog.h"
-#include "../UpdateListener.h"
-#include "../Parameter.h"
-#include "../Config.h"
-#include "../VoiceAllocationUnit.h"
-#include "../AudioOutput.h"
+#include "Request.h"
+
+class PresetController;
+class Parameter;
+class Preset;
+class VoiceAllocationUnit;
+class GenericOutput;
+class Config;
+class EditorPanel;
 
 namespace Gtk {
 	class Adjustment;
 };
 
-class EditorPanel;
 
 /**
  * @brief The top-level Graphical User Interface
@@ -47,7 +34,7 @@ class EditorPanel;
 class GUI:public Gtk::Window, public UpdateListener {
 public:
 	GUI				( Config & config, MidiController & mc, 
-					VoiceAllocationUnit & vau, int pipe[2],
+					VoiceAllocationUnit & vau, int pipe_write,
 					GenericOutput *audio, const char *title );
 	~GUI				( );
 	/**
@@ -61,20 +48,23 @@ public:
 	 * system, to allow communication between it and the system.
 	 */
 	void	setPresetController	(PresetController & p_c);
-	void	set_x_font		( const char *x_font_name );
-	string	get_x_font		( )	{ return xfontname; };
+
 	int	delete_event_impl	(GdkEventAny *);
 	int	delete_events		(GdkEventAny *, Gtk::Window *dialog)
 					{ dialog->hide_all(); return 0; };
 	void	update();
-	void	serve_request();
-private:
-	void		realize_impl		( );
+        void    onUpdate();
+
+	static void GdkInputFunction(gpointer data, gint source, GdkInputCondition condition);
+
+protected:
+	virtual void	on_hide () { Gtk::Main::quit(); }
+
+private:		
 	Gtk::MenuBar*	create_menus		( );
 
-	int *pipe, lnav;
-	void event_handler(string text);
-	void arrange();
+	int			m_pipe_write, lnav;
+	void		event_handler	(const int);
 	void config_controllers();
 	
 	void		preset_new		( );
@@ -83,11 +73,8 @@ private:
 	void		preset_paste_as_new	( );
 	
 	void		bank_open		( );
-	void		bank_open_ok		( );
-//	void		bank_save		( );
 	void		bank_save_as		( );
-	void		bank_save_as_ok		( );
-	
+
 	int		command_exists		(const char *command);
 	void		command_run		(const char *command);
 	
@@ -104,17 +91,7 @@ private:
 	// top level window & main panel
 	Gtk::Statusbar statusBar;
 	
-	
-	// about dialog
-	Gtk::Dialog about_window;
-	Gtk::Label about_label;
-	Gtk::Pixmap *about_pixmap;
-	Gtk::Button about_close_button;
-	
-	// realtime warning dialog
-	Gtk::Dialog realtime_warning;
-	Gtk::Label realtime_text_label;
-	Gtk::Button realtime_close_button;
+	Gtk::AboutDialog	aboutDlg;
 	
 	// rename preset dialog
 	Gtk::Dialog preset_rename;
@@ -127,19 +104,6 @@ private:
 	Gtk::Label		d_preset_new_label;
 	Gtk::Entry		d_preset_new_entry;
 	Gtk::Button		d_preset_new_cancel, d_preset_new_ok;
-
-	// delete preset dialog
-	Gtk::Dialog preset_delete;
-	Gtk::Label preset_delete_label;
-	Gtk::Button preset_delete_ok, preset_delete_cancel;
-	
-	// export/import preset dialog
-	Gtk::FileSelection preset_export_dialog;
-	Gtk::FileSelection preset_import_dialog;
-	
-	// export/import preset dialog
-	Gtk::FileSelection	d_bank_open;
-	Gtk::FileSelection	d_bank_save_as;
 	
 	// recording dialog
 	Gtk::Window		record_dialog;
@@ -149,19 +113,9 @@ private:
 	Gtk::Entry		record_entry;
 	Gtk::Button		record_pause, record_record, record_choose;
 	Gtk::HBox		record_buttons_hbox, record_file_hbox;
-	Gtk::FileSelection	record_fileselect;
 	Gtk::Statusbar		record_statusbar;
 	gboolean		record_recording;
-	
-	// quit confirmation dialog
-	Gtk::Dialog		quit_confirm;
-	Gtk::Label		quit_confirm_label;
-	Gtk::Button		quit_confirm_ok, quit_confirm_cancel;
-	
-	// font selection
-	Gtk::FontSelectionDialog	font_sel;
-	string				xfontname;
-	
+		
 	Gtk::Adjustment		*adj_midi,
 				*adj_voices;
 
@@ -177,6 +131,9 @@ private:
 	
 	EditorPanel		*editor_panel;
 	
-	Preset			clipboard_preset;
+	Preset			*clipboard_preset;
+        
+        std::string             m_baseName;
+        Request                 m_requestUpdate;
 };
 #endif
