@@ -1,28 +1,28 @@
 /* amSynth
- * (c) 2001,2002 Nick Dowell
+ * (c) 2001-2004 Nick Dowell
  */
 
 #ifndef _PRESETCONTROLLERVIEW_H
 #define _PRESETCONTROLLERVIEW_H
 
-#include <gtk--/box.h>
-#include <gtk--/button.h>
-#include <gtk--/combo.h>
-#include <gtk--/label.h>
+#include <gtkmm/box.h>
+#include <gtkmm/button.h>
+#include <gtkmm/combo.h>
+#include <gtkmm/label.h>
 #include <string>
 #include <list>
 #include "ParameterView.h"
-#include "../PresetController.h"
-#include "../UpdateListener.h"
-#include "../VoiceAllocationUnit.h"
+
+class PresetController;
+class UpdateListener;
+class VoiceAllocationUnit;
 
 class PresetControllerView : public UpdateListener, public Gtk::HBox {
 public:
-    PresetControllerView( int pipe_d, VoiceAllocationUnit & vau );
+    PresetControllerView(int pipe_d, VoiceAllocationUnit & vau );
     ~PresetControllerView();
     void setPresetController(PresetController & p_c);
     void update();
-	void _update_();
 private:
 	void ev_handler(string text);
     PresetController *presetController;
@@ -31,7 +31,6 @@ private:
     Gtk::Label preset_no_entry; // preset_name_entry;
 	volatile bool inhibit_combo_callback, inhibit_combo_update;
 	int piped;
-	Request request;
 	VoiceAllocationUnit *vau;
 };
 
